Live Caustics Playground
========================

Here is a little online simulator run using caustics! It's slow because it's running on a free server, but it's a good way to play with the simulator without having to install anything.

Pro tip: check out the "Pixelated" source to lens any image you want!

`Launch the simulator! <https://ciela-institute-caustics-webapp-guistreamlit-app-yanhhm.streamlit.app/>`_
